==> qt-creator-opensource-src-3.3.1.zip: qt-creator-opensource-src-3.3.1/src/plugins/debugger/gdb/gdbplainengine.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef GDBPLAINENGINE_H
#define GDBPLAINENGINE_H

#include "gdbengine.h"
#include <debugger/outputcollector.h>

namespace Debugger {
namespace Internal {

class GdbPlainEngine : public GdbEngine
{
    // Needs tr - Context
    Q_OBJECT

public:
    explicit GdbPlainEngine(const DebuggerStartParameters &startParameters);

private:
    void handleExecRun(const GdbResponse &response);
    void handleFileExecAndSymbols(const GdbResponse &response);

    void setupInferior();
    void runEngine();
    void setupEngine();
    void handleGdbStartFailed();
    void interruptInferior2();
    void shutdownEngine();

    QByteArray execFilePath() const;
    QByteArray toLocalEncoding(const QString &s) const;
    QString fromLocalEncoding(const QByteArray &b) const;

    OutputCollector m_outputCollector;
};

} // namespace Debugger
} // namespace Internal

#endif // GDBPLAINENGINE_H

==> qt-creator-opensource-src-3.4.1.zip: qt-creator-opensource-src-3.4.1/src/plugins/debugger/gdb/gdbplainengine.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef GDBPLAINENGINE_H
#define GDBPLAINENGINE_H

#include "gdbengine.h"
#include <debugger/outputcollector.h>

namespace Debugger {
namespace Internal {

class GdbPlainEngine : public GdbEngine
{
    // Needs tr - Context
    Q_OBJECT

public:
    explicit GdbPlainEngine(const DebuggerStartParameters &startParameters);

private:
    void handleExecRun(const DebuggerResponse &response);
    void handleFileExecAndSymbols(const DebuggerResponse &response);

    void setupInferior();
    void runEngine();
    void setupEngine();
    void handleGdbStartFailed();
    void interruptInferior2();
    void shutdownEngine();

    QByteArray execFilePath() const;
    QByteArray toLocalEncoding(const QString &s) const;
    QString fromLocalEncoding(const QByteArray &b) const;

    OutputCollector m_outputCollector;
};

} // namespace Debugger
} // namespace Internal

#endif // GDBPLAINENGINE_H
